@@ -10,7 +10,7 @@ def add_apps_parser(subparsers, parent_parser):
                                         description='List running applications',
                                         parents=[parent_parser])
     apps_parser.add_argument("-q", "--quiet", help="Print only long uuids", action='store_true')
-    apps_parser.add_argument("-a", "--all", help="List all applications", action='store_true')
+    apps_parser.add_argument("-s", "--status", help="Filter applications by status")
 
     # App common options
     app_common_parser = argparse.ArgumentParser(add_help=False)
@@ -81,7 +81,7 @@ def add_containers_parser(subparsers, parent_parser):
                                               description='List running containers', parents=[parent_parser])
     containers_parser.add_argument("-i", "--identifier", help="Application's uuid (either long or short) or name")
     containers_parser.add_argument("-q", "--quiet", help="Print only long uuids", action='store_true')
-    containers_parser.add_argument("-a", "--all", help="List all containers", action='store_true')
+    containers_parser.add_argument("-s", "--status", help="Filter containers by status")
 
     # Container common options
     container_common_parser = argparse.ArgumentParser(add_help=False)
